import React, { useContext, useState } from 'react'
import style from '../index.less'
import { Button, Empty, Typography, message } from 'antd'
import { DispatchAddelivery } from '..';
import { PlusCircleOutlined } from '@ant-design/icons';
import PageModal from '@/pages/launchSystemV3/components/PageModal';
const { Title, Text } = Typography;

/**
 * 落地页
 * @returns 
 */
const PageList: React.FC<{ adDataGroup?: { [x: number]: any[] } }> = ({ adDataGroup }) => {

    /********************************/
    const { addelivery, setAddelivery, accountCreateLogs, setAccountCreateLogs, clearData } = useContext(DispatchAddelivery)!;
    const { dynamic, adgroups, targeting } = addelivery

    const [addVisible, setAddVisible] = useState<boolean>(false)
    /********************************/

    return <div className={`${style.settingsBody_content_row} ${style.row6}`}>
        <div className={style.title}>
            <span>落地页</span>
        </div>
        <div className={style.detail}>
            <div className={style.detail_body}>
                {[910].includes(dynamic?.creativeTemplateId) && <Title level={5} style={{ fontSize: 12 }}>{dynamic?.landingPageType === 1 ? '平均分配' : '全部相同'}</Title>}
                {accountCreateLogs?.map((item, index) => {
                    return <div key={index}>
                        <Title level={5} style={{ fontSize: 12 }}>{item.accountId}</Title>
                        {item?.pageList?.length ?
                            item?.pageList?.map((page: { pageName: string, pageId: number }) => <div key={page.pageId} className={style.text}><Text ellipsis={{ tooltip: true }}>{page['pageName']}</Text></div>) :
                            <Empty image={Empty.PRESENTED_IMAGE_SIMPLE} style={{ margin: 0, fontSize: 12 }} imageStyle={{ height: 18 }} />}
                    </div>
                })}
            </div>
            <div className={style.detail_footer}>
                <Button disabled={!(dynamic && Object.keys(dynamic)?.length > 0)} type="link" icon={<PlusCircleOutlined />} style={{ padding: 0, fontSize: 12 }} onClick={() => setAddVisible(true)}>添加</Button>
            </div>
        </div>

        {addVisible && <PageModal
            data={accountCreateLogs}
            adgroups={adgroups}
            dynamic={dynamic}
            visible={addVisible}
            onClose={() => {
                setAddVisible(false)
            }}
            onChange={({ data, landingPageType }) => {
                if (landingPageType === 1) {
                    if (adDataGroup && Object.keys(adDataGroup).length) {
                        if (data.some(item => {
                            let total = adDataGroup[item.accountId].length
                            let pageLength = item.pageList.length
                            if (total > pageLength) {
                                message.error(`当前${item.accountId}下的广告总数（${total}）大于落地页总数（${pageLength}），平均分配需要落地页总数大于广告总数`)
                                return true
                            }
                            return false
                        })) {
                            return
                        }
                    } else {
                        let targetingLength = targeting.length
                        if (data.some(item => {
                            let productListLength = item?.productList?.length || 1
                            let total = targetingLength * productListLength
                            let pageLength = item.pageList.length
                            if (total > pageLength) {
                                message.error(`当前${item.accountId}下的广告总数（${total}）大于落地页总数（${pageLength}），平均分配需要落地页总数大于广告总数`)
                                return true
                            }
                            return false
                        })) {
                            return
                        }
                    }
                }
                setAccountCreateLogs(data);
                setAddelivery({ ...addelivery, dynamic: { ...dynamic, landingPageType } })
                setAddVisible(false);
                clearData()
            }}
        />}
    </div>
}

export default React.memo(PageList)